diff --git a/examples/hello/datamanReader/helloDataManReader_nompi.cpp b/examples/hello/datamanReader/helloDataManReader_nompi.cpp
index 7e8c982bdc2ce980f62ca32e6f2e263304690d3c..cb406b450f24970146d0fcc6f4a6e270baea18f7 100644
--- a/examples/hello/datamanReader/helloDataManReader_nompi.cpp
+++ b/examples/hello/datamanReader/helloDataManReader_nompi.cpp
@@ -43,14 +43,12 @@ int main(int argc, char *argv[])
         {
             // if not defined by user, we can change the default settings
             datamanSettings.SetEngine("DataManReader");
-            datamanSettings.SetParameters(
-                "real_time=yes", "method_type=stream", "method=zmq",
-                "local_ip=127.0.0.1", "remote_ip=127.0.0.1", "local_port=12307",
-                "remote_port=12306");
-            // datamanSettings.AddTransport( "Mdtm", "localIP=128.0.0.0.1",
-            // "remoteIP=128.0.0.0.2", "tolerances=1,2,3" );
-            // datamanSettings.AddTransport( "ZeroMQ", "localIP=128.0.0.0.1.1",
-            // "remoteIP=128.0.0.0.2.1", "tolerances=1,2,3" ); not yet supported
+            datamanSettings.SetParameters("real_time=yes", "method_type=stream",
+                                          "method=dump");
+            // datamanSettings.AddTransport( "Mdtm", "localIP=127.0.0.1",
+            // "remoteIP=127.0.0.1", "tolerances=1,2,3" );
+            // datamanSettings.AddTransport( "ZeroMQ", "localIP=127.0.0.1",
+            // "remoteIP=127.0.0.1", "tolerances=1,2,3" ); not yet supported
             // ,
             // will throw an exception
         }
@@ -67,8 +65,9 @@ int main(int argc, char *argv[])
 
         datamanReader->SetCallBack(getcb);
 
-        while (1)
+        for (int i = 0; i < 3; i++)
         {
+            std::this_thread::sleep_for(std::chrono::milliseconds(1000));
         }
 
         adios::Variable<double> *ioMyDoubles =
diff --git a/examples/hello/datamanWriter/helloDataManWriter_nompi.cpp b/examples/hello/datamanWriter/helloDataManWriter_nompi.cpp
index fa7158c37011db4a33088b714a925627348cb925..aa2aed47a3ae5779ba7cbe7155b2245d32284f44 100644
--- a/examples/hello/datamanWriter/helloDataManWriter_nompi.cpp
+++ b/examples/hello/datamanWriter/helloDataManWriter_nompi.cpp
@@ -52,10 +52,10 @@ int main(int argc, char *argv[])
                 "real_time=yes", "method_type=stream", "method=dump",
                 "monitoring=yes", "local_ip=127.0.0.1", "remote_ip=127.0.0.1",
                 "local_port=12306", "remote_port=12307");
-            // datamanSettings.AddTransport( "Mdtm", "localIP=128.0.0.0.1",
-            // "remoteIP=128.0.0.0.2", "tolerances=1,2,3" );
-            // datamanSettings.AddTransport( "ZeroMQ", "localIP=128.0.0.0.1.1",
-            // "remoteIP=128.0.0.0.2.1", "tolerances=1,2,3" ); not yet supported
+            // datamanSettings.AddTransport( "Mdtm", "localIP=127.0.0.1",
+            // "remoteIP=127.0.0.1", "tolerances=1,2,3" );
+            // datamanSettings.AddTransport( "ZeroMQ", "localIP=127.0.0.1",
+            // "remoteIP=127.0.0.1", "tolerances=1,2,3" ); not yet supported
             // ,
             // will throw an exception
         }
diff --git a/source/utilities/realtime/dataman/DataMan.cpp b/source/utilities/realtime/dataman/DataMan.cpp
index 430c8e3633f3621504033a983f1390c1fb0f3a89..eedda8a3aaa0055d31bb1bf1e797895406727405 100644
--- a/source/utilities/realtime/dataman/DataMan.cpp
+++ b/source/utilities/realtime/dataman/DataMan.cpp
@@ -38,7 +38,7 @@ void DataMan::add_file(std::string p_method) {}
 void DataMan::add_stream(json p_jmsg)
 {
 
-    std::string method = "zmq";
+    std::string method;
 
     if (p_jmsg["method"] != nullptr)
         method = p_jmsg["method"];
diff --git a/examples/hello/datamanReader/helloDataManReader.cpp b/examples/hello/datamanReader/helloDataManReader.cpp
index b3c8aa0cb50b815e1b39854130580680eca50fea..07a0099153c2b21b9dd2b54254f156ad5265fa4b 100644
--- a/examples/hello/datamanReader/helloDataManReader.cpp
+++ b/examples/hello/datamanReader/helloDataManReader.cpp
@@ -51,11 +51,11 @@ int main(int argc, char *argv[])
             // if not defined by user, we can change the default settings
             datamanSettings.SetEngine("DataManReader");
             datamanSettings.SetParameters("peer-to-peer=yes");
-            datamanSettings.AddTransport("Mdtm", "localIP=128.0.0.0.1",
-                                         "remoteIP=128.0.0.0.2",
+            datamanSettings.AddTransport("Mdtm", "localIP=127.0.0.1",
+                                         "remoteIP=127.0.0.1",
                                          "tolerances=1,2,3");
             // datamanSettings.AddTransport( "ZeroMQ", "localIP=128.0.0.0.1.1",
             // "remoteIP=128.0.0.0.2.1", "tolerances=1,2,3" ); not yet supported
             // ,
             // will throw an exception
         }
@@ -51,11 +51,11 @@ int main(int argc, char *argv[])
                                          "tolerances=1,2,3");
-            // datamanSettings.AddTransport( "ZeroMQ", "localIP=128.0.0.0.1.1",
-            // "remoteIP=128.0.0.0.2.1", "tolerances=1,2,3" ); not yet supported
+            // datamanSettings.AddTransport( "ZeroMQ", "localIP=127.0.0.1",
+            // "remoteIP=127.0.0.1", "tolerances=1,2,3" ); not yet supported
             // ,
             // will throw an exception